==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebMaskInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebMaskInputDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMaskInputDescription, _super);
    function WebMaskInputDescription() {
        var _this = _super.call(this) || this;
        _this.ae = null;
        _this.ac = false;
        _this.ai = null;
        _this.ah = null;
        _this.af = null;
        _this.ag = null;
        return _this;
    }
    WebMaskInputDescription.prototype.get_type = function () {
        return "WebMaskInput";
    };
    Object.defineProperty(WebMaskInputDescription.prototype, "dir", {
        get: function () {
            return this.ae;
        },
        set: function (a) {
            this.ae = a;
            this.e("Dir");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "invalid", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Invalid");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "valueMode", {
        get: function () {
            return this.ai;
        },
        set: function (a) {
            this.ai = a;
            this.e("ValueMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "value", {
        get: function () {
            return this.ah;
        },
        set: function (a) {
            this.ah = a;
            this.e("Value");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "mask", {
        get: function () {
            return this.af;
        },
        set: function (a) {
            this.af = a;
            this.e("Mask");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "prompt", {
        get: function () {
            return this.ag;
        },
        set: function (a) {
            this.ag = a;
            this.e("Prompt");
        },
        enumerable: false,
        configurable: true
    });
    WebMaskInputDescription.$t = markType(WebMaskInputDescription, 'WebMaskInputDescription', WebInputBaseDescription.$);
    return WebMaskInputDescription;
}(WebInputBaseDescription));
export { WebMaskInputDescription };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebMaskInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebMaskInputBaseDescription } from "./WebMaskInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebMaskInputDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebMaskInputDescription, _super);
    function WebMaskInputDescription() {
        var _this = _super.call(this) || this;
        _this.ai = null;
        _this.ah = null;
        _this.ag = null;
        return _this;
    }
    WebMaskInputDescription.prototype.get_type = function () {
        return "WebMaskInput";
    };
    Object.defineProperty(WebMaskInputDescription.prototype, "valueMode", {
        get: function () {
            return this.ai;
        },
        set: function (a) {
            this.ai = a;
            this.e("ValueMode");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "value", {
        get: function () {
            return this.ah;
        },
        set: function (a) {
            this.ah = a;
            this.e("Value");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebMaskInputDescription.prototype, "mask", {
        get: function () {
            return this.ag;
        },
        set: function (a) {
            this.ag = a;
            this.e("Mask");
        },
        enumerable: false,
        configurable: true
    });
    WebMaskInputDescription.$t = markType(WebMaskInputDescription, 'WebMaskInputDescription', WebMaskInputBaseDescription.$);
    return WebMaskInputDescription;
}(WebMaskInputBaseDescription));
export { WebMaskInputDescription };
